@@ -2,14 +2,13 @@ package Alien::Base::ModuleBuild::Repository;
 
 use strict;
 use warnings;
-
-our $VERSION = '1.08';
-
 use Carp;
-
 use Alien::Base::ModuleBuild::File;
 use Alien::Base::ModuleBuild::Utils qw/pattern_has_capture_groups/;
 
+# ABSTRACT: Private class
+our $VERSION = '1.10'; # VERSION
+
 sub new {
   my $class = shift;
   my (%self) = ref $_[0] ? %{ shift() } : @_;
@@ -93,3 +92,65 @@ sub get_file  { croak "$_[0] doesn't provide 'get_files' method"  }
 
 1;
 
+__END__
+
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+Alien::Base::ModuleBuild::Repository - Private class
+
+=head1 VERSION
+
+version 1.10
+
+=head1 AUTHOR
+
+Original author: Joel A Berger E<lt>joel.a.berger@gmail.comE<gt>
+
+Current maintainer: Graham Ollis E<lt>plicease@cpan.orgE<gt>
+
+Contributors:
+
+David Mertens (run4flat)
+
+Mark Nunberg (mordy, mnunberg)
+
+Christian Walde (Mithaldu)
+
+Brian Wightman (MidLifeXis)
+
+Graham Ollis (plicease)
+
+Zaki Mughal (zmughal)
+
+mohawk2
+
+Vikas N Kumar (vikasnkumar)
+
+Flavio Poletti (polettix)
+
+Salvador Fandiño (salva)
+
+Gianni Ceccarelli (dakkar)
+
+Pavel Shaydo (zwon, trinitum)
+
+Kang-min Liu (劉康民, gugod)
+
+Nicholas Shipp (nshp)
+
+Petr Pisar (ppisar)
+
+Alberto Simões (ambs)
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2012-2020 by Joel A Berger.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
