@@ -2,19 +2,16 @@ package Alien::Base::ModuleBuild::Repository::HTTP;
 
 use strict;
 use warnings;
-
-our $VERSION = '1.07';
-
 use Carp;
-
 use HTTP::Tiny;
 use Scalar::Util qw( blessed );
 use URI;
-
 use Alien::Base::ModuleBuild::Utils;
-
 use parent 'Alien::Base::ModuleBuild::Repository';
 
+# ABSTRACT: HTTP repository handler
+our $VERSION = '1.10'; # VERSION
+
 our $Has_HTML_Parser = eval { require HTML::LinkExtor; 1 };
 
 sub connection {
@@ -79,12 +76,12 @@ sub list_files {
     carp $content;
     return ();
   }
-  
+
   $self->{base_url} = $base_url;
 
   my @links = $self->find_links($content);
 
-  return @links;  
+  return @links;
 }
 
 sub find_links {
@@ -93,7 +90,7 @@ sub find_links {
 
   my @links;
   if ($Has_HTML_Parser) {
-    push @links, $self->find_links_preferred($html) 
+    push @links, $self->find_links_preferred($html)
   } else {
     push @links, $self->find_links_textbalanced($html)
   }
@@ -108,7 +105,7 @@ sub find_links_preferred {
   my @links;
 
   my $extor = HTML::LinkExtor->new(
-    sub { 
+    sub {
       my ($tag, %attrs) = @_;
       return unless $tag eq 'a';
       return unless defined $attrs{href};
@@ -174,3 +171,65 @@ sub check_http_response {
 
 1;
 
+__END__
+
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+Alien::Base::ModuleBuild::Repository::HTTP - HTTP repository handler
+
+=head1 VERSION
+
+version 1.10
+
+=head1 AUTHOR
+
+Original author: Joel A Berger E<lt>joel.a.berger@gmail.comE<gt>
+
+Current maintainer: Graham Ollis E<lt>plicease@cpan.orgE<gt>
+
+Contributors:
+
+David Mertens (run4flat)
+
+Mark Nunberg (mordy, mnunberg)
+
+Christian Walde (Mithaldu)
+
+Brian Wightman (MidLifeXis)
+
+Graham Ollis (plicease)
+
+Zaki Mughal (zmughal)
+
+mohawk2
+
+Vikas N Kumar (vikasnkumar)
+
+Flavio Poletti (polettix)
+
+Salvador Fandiño (salva)
+
+Gianni Ceccarelli (dakkar)
+
+Pavel Shaydo (zwon, trinitum)
+
+Kang-min Liu (劉康民, gugod)
+
+Nicholas Shipp (nshp)
+
+Petr Pisar (ppisar)
+
+Alberto Simões (ambs)
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2012-2020 by Joel A Berger.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
